/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.intent;

import java.util.Map;
import com.google.common.collect.ImmutableMap;

/**
 * Representation of common RPC result.
 */
public interface CommonRpcResult {

    /**
     * Returns result code.
     *
     * @return result code
     */
    Code getResultCode();

    /**
     * Returns message.
     *
     * @return message
     */
    String getMessage();

    /**
     * Representation of result code enum.
     */
    enum Code {

        /**
         * The invoked RPC was executed successfully.
         */
        OK(0),

        /**
         * An error occurred while executing the RPC.
         */
        ERROR(1);

        private static final Map<Integer, Code> VALUE_MAP;

        int value;

        Code(int value) {
            this.value = value;
        }

        /**
         * Returns integer value.
         *
         * @return integer value
         */
        public int intValue() {
            return value;
        }

        static {
            ImmutableMap.Builder<Integer, Code> b = ImmutableMap.builder();
            for (Code enumItem : Code.values()) {
                b.put(enumItem.value, enumItem);
            }
            VALUE_MAP = b.build();
        }

        /**
         * Returns result code by value.
         *
         * @param value a map key value
         * @return corresponding result code constant
         */
        public static Code forValue(int value) {
            Code code = VALUE_MAP.get(value);
            if (code == null) {
                throw new IllegalArgumentException(
                        String.format("Param %d is not valid", value));
            }
            return code;
        }
    }
}