/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.object.match.item.definitions;

import static com.google.common.base.MoreObjects.toStringHelper;

import java.util.Objects;

import org.onosproject.nemo.model.common.MatchItemName;

/**
 * The key to match item definition.
 */
public class MatchItemDefinitionKey {
    private final MatchItemName matchItemName;

    /**
     * Creates a match item name from a given match item name.
     *
     * @param matchItemName the match item name
     */
    public MatchItemDefinitionKey(MatchItemName matchItemName) {
        this.matchItemName = matchItemName;
    }

    /**
     * Creates a copy from source object.
     *
     * @param source the source object
     */
    public MatchItemDefinitionKey(MatchItemDefinitionKey source) {
        matchItemName = source.matchItemName;
    }

    /**
     * Returns the match item name of this instance.
     *
     * @return the match item name
     */
    public MatchItemName getMatchItemName() {
        return matchItemName;
    }

    @Override
    public int hashCode() {
        return matchItemName.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        MatchItemDefinitionKey other = (MatchItemDefinitionKey) obj;
        return Objects.equals(matchItemName, other.matchItemName);
    }

    @Override
    public String toString() {
        return toStringHelper(this)
                .add("matchItemName", matchItemName)
                .toString();
    }
}