/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.object.property.instance.property.values;

import java.util.Objects;

import static com.google.common.base.MoreObjects.toStringHelper;

/**
 * The key to differentiate integer value.
 */
public class IntValueKey {
    private final long value;
    private final long order;

    /**
     * Creates a integer value key from a given value.
     *
     * @param order integer value key order
     * @param value the integer value
     */
    public IntValueKey(long order, long value) {
        this.value = value;
        this.order = order;
    }

    /**
     * Creates a copy from a given integer value key instance.
     *
     * @param key the integer value key
     */
    public IntValueKey(IntValueKey key) {
        value = key.value;
        order = key.order;
    }

    /**
     * Returns the value of this instance.
     *
     * @return value,if it exists
     */
    public long getValue() {
        return value;
    }

    /**
     * Returns the order of this instance.
     *
     * @return order,if it exists
     */
    public long getOrder() {
        return order;
    }

    @Override
    public int hashCode() {
        return Objects.hash(value, order);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        IntValueKey o = (IntValueKey) obj;
        return value == o.value && order == o.order;
    }

    @Override
    public String toString() {
        return toStringHelper(this).add("value", value)
                .add("order", order)
                .toString();
    }
}