/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation.condition.instance;

import org.onosproject.nemo.model.common.ConditionSegmentId;

import static com.google.common.base.MoreObjects.toStringHelper;

import java.util.Objects;

/**
 * Key of ConditionSegment.
 */
public class ConditionSegmentKey {

    private final ConditionSegmentId conditionSegmentId;

    /**
     * Creates a copy from condition segment Id.
     *
     * @param conditionSegmentId condition segment Id
     */
    public ConditionSegmentKey(ConditionSegmentId conditionSegmentId) {
        this.conditionSegmentId = conditionSegmentId;
    }

    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public ConditionSegmentKey(ConditionSegmentKey source) {
        this.conditionSegmentId = source.conditionSegmentId;
    }

    /**
     * Returns the condition segment Id of this instance.
     *
     * @return value
     */
    public ConditionSegmentId getConditionSegmentId() {
        return conditionSegmentId;
    }


    @Override
    public int hashCode() {
        return Objects.hash(conditionSegmentId);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        ConditionSegmentKey other = (ConditionSegmentKey) obj;
        return Objects.equals(conditionSegmentId, other.conditionSegmentId);
    }

    @Override
    public String toString() {
        return toStringHelper(this)
                .add("conditionSegmentId", conditionSegmentId)
                .toString();
    }
}

