/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.common;

import com.google.common.testing.EqualsTester;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

/**
 * Unit tests for {@link ConstraintParameterName}.
 */
public class ConstraintParameterNameTest {

    private static final String NAME = "SomeName";
    private static final String OTHER = "OtherName";

    private ConstraintParameterName name;
    private ConstraintParameterName copy;
    private ConstraintParameterName diff;

    @Test
    public void fromString() {
        name = new ConstraintParameterName(NAME);
        assertEquals("name not set", NAME, name.getValue());
    }

    @Test
    public void copyConstructor() {
        name = new ConstraintParameterName(NAME);
        copy = new ConstraintParameterName(name);
        new EqualsTester()
                .addEqualityGroup(name, copy)
                .testEquals();
    }

    @Test
    public void equality() {
        name = new ConstraintParameterName(NAME);
        copy = new ConstraintParameterName(NAME);
        diff = new ConstraintParameterName(OTHER);
        new EqualsTester()
                .addEqualityGroup(name, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}