package org.onosproject.nemo.model.object.node.instance;

import static junit.framework.Assert.assertEquals;

import org.junit.Test;
import org.onosproject.nemo.model.common.NodeId;
import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link SubNodeBuilder}.
 */
public class SubNodeBuilderTest {

    private static final String NODEID = "14ce424a-3e50-4a2a-ad5c-b29845158c8b";
    private static final String OTHER = "a4ce424a-3e50-4a2a-ad5c-b29845158c8b";
    private static final String NODEID_ERROR_MSG = "node id not set";
    private static final String KEY_ERROR_MSG = "key not set";
    private SubNodeKey key;
    private NodeId name;
    private NodeId otherName;
    private SubNode listParam;
    private SubNode def;
    private SubNode copy;
    private SubNode diff;

    @Test
    public void buildSubNodeWithSubNodeKey() {
        name = new NodeId(NODEID);
        key = new SubNodeKey(name);
        listParam = new SubNodeBuilder()
                .key(key)
                .build();
        def = new SubNodeBuilder()
                .key(key)
                .addAugmentation(SubNode.class, listParam)
                .build();
        def = new SubNodeBuilder(def)
                .addAugmentation(SubNode.class, null)
                .build();
        assertEquals(NODEID_ERROR_MSG, name, def.getNodeId());
        assertEquals(KEY_ERROR_MSG, key, def.getKey());
    }

    @Test
    public void buildSubNodeWithSubNodeName() {
        name = new NodeId(NODEID);
        key = new SubNodeKey(name);
        listParam = new SubNodeBuilder()
                .nodeId(name)
                .build();
        def = new SubNodeBuilder()
                .nodeId(name)
                .addAugmentation(SubNode.class, listParam)
                .build();
        def = new SubNodeBuilder(def)
                .addAugmentation(SubNode.class, null)
                .build();
        assertEquals(NODEID_ERROR_MSG, name, def.getNodeId());
        assertEquals(KEY_ERROR_MSG, key, def.getKey());
    }

    @Test
    public void fromSubNodeWithSubNodeKey() {
        name = new NodeId(NODEID);
        key = new SubNodeKey(name);
        def = new SubNodeBuilder()
                .key(key)
                .build();
        copy = new SubNodeBuilder(def).build();
        assertEquals(NODEID_ERROR_MSG, name, copy.getNodeId());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
    }

    @Test
    public void fromSubNodeWithSubNodeName() {
        name = new NodeId(NODEID);
        key = new SubNodeKey(name);
        def = new SubNodeBuilder()
                .nodeId(name)
                .build();
        copy = new SubNodeBuilder(def).build();
        assertEquals(NODEID_ERROR_MSG, name, copy.getNodeId());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
    }

    @Test
    public void equality() {
        name = new NodeId(NODEID);
        def = new SubNodeBuilder()
                .nodeId(name)
                .build();
        copy = new SubNodeBuilder()
                .nodeId(name)
                .build();
        otherName = new NodeId(OTHER);
        diff = new SubNodeBuilder()
                .nodeId(otherName)
                .build();
        new EqualsTester()
                .addEqualityGroup(def, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}