/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation.action.definitions;

import static org.junit.Assert.assertEquals;

import org.junit.Test;
import org.onosproject.nemo.model.common.ActionName;

import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link ActionDefinitionKey}.
 */
public class ActionDefinitionKeyTest {

    private static final String NAME = "SomeName";
    private static final String OTHER = "OtherName";
    private static final String NAME_ERROR_MSG = "name not set";

    private ActionDefinitionKey key;
    private ActionDefinitionKey copy;
    private ActionDefinitionKey diff;

    @Test
    public void fromActionName() {
        key = new ActionDefinitionKey(new ActionName(NAME));
        assertEquals(NAME_ERROR_MSG, NAME, key.getActionName().getValue());
    }

    @Test
    public void copyConstructor() {
        key = new ActionDefinitionKey(new ActionName(NAME));
        copy = new ActionDefinitionKey(key);
        new EqualsTester()
                .addEqualityGroup(key, copy)
                .testEquals();
    }

    @Test
    public void equality() {
        key = new ActionDefinitionKey(new ActionName(NAME));
        copy = new ActionDefinitionKey(new ActionName(NAME));
        diff = new ActionDefinitionKey(new ActionName(OTHER));
        new EqualsTester()
                .addEqualityGroup(key, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}